import {
  IEventParam,
  Loader,
  Metadata,
  IDictionary,
  Config,
} from '@zeedhi/core';

import {
  GridEditable, Form, TextInput, Modal, ModalService,
} from '@zeedhi/common';

import { PmeMask } from '@/config';
  
export class Ger30000PadraoDeServicoController {
  public gridEditController = Loader.getInstance('GridEditableController');
  
  public modalController = Loader.getInstance('ModalController');

  public crudController = Loader.getInstance('CrudController');

  public utilities = Loader.getInstance('Utilities');
  
  public appController = Loader.getInstance('AppController');
  
  public fillCode({ component }: IEventParam<TextInput>) {
    component.value = component.value.padStart(5, '0');
  }
  
  public visibilidadeAcaoAtualizar = true;
  
  private modalConfigCard!: Modal;
  
  public async criaPadraoServicoModal() {
    this.modalController.createModal('/modals/ger30002_padrao_de_servico');
    this.modalConfigCard = await ModalService.createFromJson('/modals/closeButtonModal', true);
  }
  
  public destroiPadraoServicoModal() {
    this.modalController.destroyModal();
  }
  
  public abreModalPadraoDeServico() {
    this.modalController.openModal();
  }
  
  public cancelModal() {
    this.modalConfigCard.hide();
    this.modalConfigCard.destroy();
    this.modalController.closeModal();
  }
  
  public savePadraoServico() {
    const formPadraoServico = Metadata.getInstance<Form>('formPadraoDeServico');
    const gridPadraoServico: GridEditable = Metadata.getInstance('gridPadraoDeServico');
    const editedRows: IDictionary = gridPadraoServico.getEditedRows();
    if (formPadraoServico.validate() && editedRows.length > 0) {
      editedRows.forEach((row: IDictionary) => {
        if (row.__is_new) {
          row.CDSERVPADR = row.CDSERVPADR.padStart(5, '0');
        }
      });
      this.crudController.saveRows(editedRows, 'servpadr', gridPadraoServico).then(() => {
        this.gridEditController.defaultState(gridPadraoServico);
        this.utilities.showAlert('alert', 'pme::salvoComSucesso', 'success');
      }).catch((error: string) => {
        this.utilities.showAlert('alert', `pme::${error}`, 'error');
      });
    }
  }
  
  public produtoComponentProps = {
    component: 'ZdSelect',
    dataText: [
      {
        name: 'CDARVPROD',
        mask: (Config.masks.productMask as PmeMask).pattern,
      },
      'NMPRODUTO',
    ],
    formatterDataText: [
      {
        name: 'CDARVPROD',
        mask: (Config.masks.productMask as PmeMask).pattern,
      },
      'NMPRODUTO',
    ],
    dataValueOut: [
      {
        column: 'CDARVPROD',
        columnOnGrid: 'CDARVPROD',
      },
      {
        column: 'NMPRODUTO',
        columnOnGrid: 'NMPRODUTO',
      },
    ],
    dataValue: 'CDPRODUTO',
    dense: true,
    datasource: {
      uniqueKey: 'CDPRODUTO',
      route: '/prodUltimoNivel',
      type: 'rest',
      limit: 10,
      lazyLoad: true,
    },
    validations: {
      required: {
        message: 'pme::campoObrigatorio',
      },
    },
  };
  
  public verificaVisibilidadeAcaoAtualizar() {
    const gridPadraoServico: GridEditable = Metadata.getInstance('gridPadraoDeServico');
    const selectedRows = gridPadraoServico.selectedRows;
    if (selectedRows.length > 0) {
      this.visibilidadeAcaoAtualizar = false;
    } else {
      this.visibilidadeAcaoAtualizar = true;
    }
  }
}
